@@ -1,14 +1,12 @@
-# -*- coding: utf-8 -*-
-from django.conf import settings
-from django.core.serializers.base import Serializer
-from django.utils.translation import ugettext_lazy as _
-from django.contrib.gis.geos.collections import GeometryCollection
-from django.contrib.gis.geos import Point, LineString, Polygon
-
 import gpxpy.gpx
+from django.conf import settings
+from django.contrib.gis.geos import Point, LineString, Polygon
+from django.contrib.gis.geos.collections import GeometryCollection
+from django.core.serializers.base import Serializer
+from django.utils.translation import gettext_lazy as _
 
-from ..templatetags.mapentity_tags import humanize_timesince
 from ..settings import app_settings
+from ..templatetags.mapentity_tags import humanize_timesince
 
 
 class GPXSerializer(Serializer):
@@ -38,17 +36,18 @@ class GPXSerializer(Serializer):
     def end_object(self, obj):
         """ Single object serialization.
         """
-        objtype = unicode(obj.__class__._meta.verbose_name)
-        name = u'[%s] %s' % (objtype, unicode(obj))
+        objtype = obj.__class__._meta.verbose_name
+        name = '[%s] %s' % (objtype, (obj))
         description = getattr(obj, 'description', '')
         objupdate = obj.get_date_update()
         if objupdate:
             description += _('Modified') + ': ' + humanize_timesince(objupdate)
-
-        geom_field = self.options.pop('geom_field', app_settings['GEOM_FIELD_NAME'])
+        geom_field = self.options.pop('gpx_field', app_settings['GPX_FIELD_NAME'])
         geom = getattr(obj, geom_field, None)
+        if not geom:
+            geom = getattr(obj, app_settings['GEOM_FIELD_NAME'], None)
         if geom:
-            assert geom.srid == settings.SRID, "Invalid SRID (!= %s)" % settings.SRID
+            # assert geom.srid == settings.SRID, f"Invalid SRID ({geom.srid}!= {settings.SRID})"
             self.geomToGPX(geom, name, description)
 
     def _point_to_GPX(self, point, klass=gpxpy.gpx.GPXWaypoint):
@@ -69,7 +68,7 @@ class GPXSerializer(Serializer):
         """
         if isinstance(geom, GeometryCollection):
             for i, g in enumerate(geom):
-                self.geomToGPX(g, u"%s (%s)" % (name, i), description)
+                self.geomToGPX(g, "%s (%s)" % (name, i), description)
         elif isinstance(geom, Point):
             wp = self._point_to_GPX(geom)
             wp.name = name
